@@ -18,23 +18,23 @@
 
 #include <gtk/gtk.h>
 #include <gtk/gtknotebook.h>
-#include "pp_printoutput.h"
+#include "gp_cppsupport/printoutputselector.h"
 #include "pp_cms.h"
 #include "pp_units.h"
 #include "pp_scaling.h"
 #include "stpui_widgets/stpui_optionbook.h"
 #include "splashscreen/splashscreen.h"
-#include "support/patheditor.h"
+#include "miscwidgets/patheditor.h"
 #include "support/pathsupport.h"
-#include "support/imageselector.h"
-#include "support/generaldialogs.h"
+#include "miscwidgets/imageselector.h"
+#include "miscwidgets/generaldialogs.h"
 #include "support/rangeparser.h"
 #include "support/progressbar.h"
-#include "support/tiffsave.h"
-#include "support/jpegsave.h"
+#include "imageutils/tiffsave.h"
+#include "imageutils/jpegsave.h"
 #include "profilemanager/profileselector.h"
 #include "profilemanager/intentselector.h"
-#include "util.h"
+#include "support/util.h"
 #include "config.h"
 #include "gettext.h"
 #define _(x) gettext(x)
@@ -103,7 +103,7 @@ static void driver_changed(GtkWidget *wid,gpointer data)
 		cerr << "Setting driver failed - reverting to default" << endl;
 		po->SetString("Driver",DEFAULT_PRINTER_DRIVER);
 		cbd->state->printer.SetDriver(po->FindString("Driver"));
-		pp_printoutput_refresh(PP_PRINTOUTPUT(cbd->printoutput));
+		printoutputselector_refresh(PRINTOUTPUTSELECTOR(cbd->printoutput));
 	}
 
 	stpui_optionbook_rebuild(STPUI_OPTIONBOOK(cbd->optionbook));	
@@ -129,7 +129,7 @@ void PrintSetup_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 
 	cerr << "Creating PrintOutput widget..." << endl;
 
-	dialogdata.printoutput=pp_printoutput_new(&state.printoutput);
+	dialogdata.printoutput=printoutputselector_new(&state.printoutput);
 	g_object_ref(G_OBJECT(dialogdata.printoutput));
 
 	cerr << "Created PrintOutput widget..." << endl;
@@ -184,7 +184,7 @@ void About_Dialog(GtkWindow *parent)
 	
 	GtkWidget *label=gtk_label_new("PhotoPrint "
 	PACKAGE_VERSION
-	" - copyright (c) 2004-2008\n"
+	" - copyright (c) 2004-2009\n"
 	"by Alastair M. Robinson (amr@blackfiveservices.co.uk)\nDistributed under the terms\nof the GNU General Public Licence.\n"
 	"See the file 'COPYING' for more details.");
 	gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_CENTER);
@@ -824,7 +824,7 @@ static void refreshprofiledialog(GtkWidget *wid,gpointer obj)
 	bool profileactive=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(st->profenabled));
 
 	if(profile)
-		profile=st->state->profilemanager.Search(profile);
+		profile=st->state->profilemanager.SearchPaths(profile);
 
 	cerr << "Got profileactive: " << profileactive << endl;
 	if(profile)
