@@ -56,17 +56,20 @@ ISDataType *ImageSource_HDownsample::GetRow(int row)
 		return(rowbuffer);
 	currentrow=row;
 
-	// We accumulate pixel values from a potentially large number of pixels
-	// and process all the samples in a pixel at one time.
+	// We accumulate pixel values from a potentially
+	// large number of pixels and process all the samples
+	// in a pixel at one time.
 	double tmp[IS_MAX_SAMPLESPERPIXEL];
 	for(int i=0;i<samplesperpixel;++i)
 		tmp[i]=0;
 
 	ISDataType *srcdata=source->GetRow(row);
 
-	// We use a Bresenham-esque method of calculating the pixel boundaries for scaling
-	// - add the smaller value to an accumulator until it exceeds the larger value,
-	// then subtract the larger value, leaving the remainder in place for the next round.
+	// We use a Bresenham-esque method of calculating the
+	// pixel boundaries for scaling - add the smaller value
+	// to an accumulator until it exceeds the larger value,
+	// then subtract the larger value, leaving the remainder
+	// in place for the next round.
 	int a=0;
 	int src=0;
 	int dst=0;
@@ -75,7 +78,8 @@ ISDataType *ImageSource_HDownsample::GetRow(int row)
 		// Add the smaller value (destination width)
 		a+=width;
 
-		// As long as the counter is less than the larger value, we take full pixels.
+		// As long as the counter is less than the larger value
+		// (source width), we take full pixels.
 		while(a<source->width)
 		{
 			if(src>=source->width)
@@ -88,12 +92,15 @@ ISDataType *ImageSource_HDownsample::GetRow(int row)
 
 		double p=source->width-(a-width);
 		p/=width;
-		// p now contains the proportion of the next pixel to be counted towards the output pixel.
+		// p now contains the proportion of the next pixel
+		// to be counted towards the output pixel.
 
 		a-=source->width;
-		// And a now contains the remainder, ready for the next round.
+		// And a now contains the remainder,
+		// ready for the next round.
 
-		// So we add p * the new source pixel to the current output pixel...
+		// So we add p * the new source pixel
+		// to the current output pixel...
 		if(src>=source->width)
 			src=source->width-1;
 		for(int i=0;i<samplesperpixel;++i)
@@ -101,10 +108,14 @@ ISDataType *ImageSource_HDownsample::GetRow(int row)
 
 		// Store it...
 		for(int i=0;i<samplesperpixel;++i)
-			rowbuffer[samplesperpixel*dst+i]=0.5+(tmp[i]*width)/source->width;
+		{
+			rowbuffer[samplesperpixel*dst+i] =
+				0.5+(tmp[i]*width)/source->width;
+		}
 		++dst;
 
-		// And start off the next output pixel with (1-p) * the source pixel.
+		// And start off the next output pixel with
+		// (1-p) * the source pixel.
 		for(int i=0;i<samplesperpixel;++i)
 			tmp[i]=(1.0-p)*srcdata[samplesperpixel*src+i];
 		++src;
@@ -117,6 +128,7 @@ ISDataType *ImageSource_HDownsample::GetRow(int row)
 ImageSource_HDownsample::ImageSource_HDownsample(struct ImageSource *source,int width)
 	: ImageSource(source), source(source)
 {
+	cerr << "Using hdownsample filter" << endl;
 	this->width=width;
 	xres=(source->xres*width); xres/=source->width;
 
@@ -189,6 +201,7 @@ ISDataType *ImageSource_VDownsample::GetRow(int row)
 ImageSource_VDownsample::ImageSource_VDownsample(struct ImageSource *source,int height)
 	: ImageSource(source), source(source), tmp(NULL), srcrow(0), acc(0)
 {
+	cerr << "Using vdownsample filter" << endl;
 	this->height=height;
 	yres=(source->yres*height); yres/=source->height;
 	randomaccess=false;
