@@ -117,7 +117,7 @@ void ImageSource_GdkPixbuf::Init()
 	if(gdk_pixbuf_get_bits_per_sample(pixbuf)!=8)
 		throw "GdxPixbuf loader doesn't yet support 16 bit images\n"\
 		"Please contact me at blackfive@fakenhamweb.co.uk\n"\
-		"And I'll try to add support.";
+		"And I'll try to add native support for this file format.";
 
 	type=IS_TYPE_RGB;
 	samplesperpixel=3;
