@@ -3,7 +3,7 @@
  * Composites multiple images into a single image.
  * Supports Random Access if and only if all source images also support it.
  *
- * Copyright (c) 2004, 2005 by Alastair M. Robinson
+ * Copyright (c) 2004-2008 by Alastair M. Robinson
  * Distributed under the terms of the GNU General Public License -
  * see the file named "COPYING" for more details.
  *
@@ -93,27 +93,34 @@ ISMontage_Component::~ISMontage_Component()
 }
 
 
-ImageSource_Montage::ImageSource_Montage(IS_TYPE type,int resolution)
+ImageSource_Montage::ImageSource_Montage(IS_TYPE type,int resolution, int samplesperpixel)
 	: ImageSource(), first(NULL)
 {
 	xres=resolution;
 	yres=resolution;
 	this->type=type;
+	this->samplesperpixel=samplesperpixel;
 
 	switch(type)
 	{
-		case IS_TYPE_BW:
+//		case IS_TYPE_BW:
 		case IS_TYPE_GREY:
-			samplesperpixel=1;
+			this->samplesperpixel=1;
 			break;
+//		case ISTYPE_GREYA:
+//			this->samplesperpixel=2;
+//			break;
 		case IS_TYPE_RGB:
-			samplesperpixel=3;
+			this->samplesperpixel=3;
 			break;
+		case IS_TYPE_RGBA:
 		case IS_TYPE_CMYK:
-			samplesperpixel=4;
+			this->samplesperpixel=4;
+			break;
+		case IS_TYPE_DEVICEN:
 			break;
 		default:
-			throw "Unsupported image type";
+			throw "Montage: unsupported type";
 	}
 
 #ifdef MONTAGE_RANDOM_ACCESS
@@ -135,7 +142,7 @@ ImageSource_Montage::~ImageSource_Montage()
 
 void ImageSource_Montage::Add(ImageSource *is,int xpos,int ypos)
 {
-	if(STRIP_ALPHA(is->type)!=type)
+	if(STRIP_ALPHA(is->type)!=STRIP_ALPHA(type))
 		throw "Can't yet mix different colour spaces on one page";
 	new ISMontage_Component(this,is,xpos,ypos);
 
@@ -151,8 +158,17 @@ ISDataType *ImageSource_Montage::GetRow(int row)
 	ISDataType *src;
 	ISDataType *dst=rowbuffer;
 
-	switch(STRIP_ALPHA(type))
+	switch(type)
 	{
+		case IS_TYPE_RGBA:
+			for(int i=0;i<width*samplesperpixel;i+=samplesperpixel)
+			{
+				dst[i]=IS_SAMPLEMAX;
+				dst[i+1]=IS_SAMPLEMAX;
+				dst[i+2]=IS_SAMPLEMAX;
+				dst[i+3]=0;
+			}
+			break;
 		case IS_TYPE_RGB:
 			for(int i=0;i<width*samplesperpixel;++i)
 				dst[i]=IS_SAMPLEMAX;
@@ -170,27 +186,80 @@ ISDataType *ImageSource_Montage::GetRow(int row)
 		{
 			if(HAS_ALPHA(mc->source->type))
 			{
-				for(int i=0;i<mc->source->width;++i)
+				if(HAS_ALPHA(type))
 				{
-					int a=src[(i+1)*mc->source->samplesperpixel-1];
-//					cerr << "Alpha: " << a << endl;
-					int ia=IS_SAMPLEMAX-a;
-					int xp=(mc->xpos+i)*samplesperpixel;
-					int sp=i*mc->source->samplesperpixel;
-					for(int j=0;j<samplesperpixel;++j)
+					// If the target image has an alpha channel too, then we
+					// must choose a target alpha value.  Perhaps the highest alpha
+					// level encountered?
+					for(int i=0;i<mc->source->width;++i)
 					{
-						int t=dst[xp+j];
-						t*=ia;
-						int t2=src[sp+j];
-						t2*=a;
-						dst[xp+j]=(t+t2)/IS_SAMPLEMAX;
+						int a=src[(i+1)*mc->source->samplesperpixel-1];
+						int ia=IS_SAMPLEMAX-a;
+						int xp=(mc->xpos+i)*samplesperpixel;
+						int sp=i*mc->source->samplesperpixel;
+						int j;
+						for(j=0;j<samplesperpixel-1;++j)
+						{
+							int t=dst[xp+j];
+							t*=ia;
+							int t2=src[sp+j];
+							t2*=a;
+							dst[xp+j]=(t+t2)/IS_SAMPLEMAX;
+						}
+						if(a>0)
+						{
+							if(dst[xp+j]<a)
+								dst[xp+j]=a;
+//							dst[xp+j]=ia;
+						}
+//						if(dst[xp+j]>a)
+//							dst[xp+j]=0;
+//							dst[xp+j]=0;
+					}
+				}
+				else
+				{
+					// The source image has an alpha channel, but is being composited
+					// onto an image without.
+					for(int i=0;i<mc->source->width;++i)
+					{
+						int a=src[(i+1)*mc->source->samplesperpixel-1];
+//						cerr << "Alpha: " << a << endl;
+						int ia=IS_SAMPLEMAX-a;
+						int xp=(mc->xpos+i)*samplesperpixel;
+						int sp=i*mc->source->samplesperpixel;
+						for(int j=0;j<samplesperpixel;++j)
+						{
+							int t=dst[xp+j];
+							t*=ia;
+							int t2=src[sp+j];
+							t2*=a;
+							dst[xp+j]=(t+t2)/IS_SAMPLEMAX;
+						}
 					}
 				}
 			}
 			else
 			{
-				for(int i=0;i<mc->source->width*samplesperpixel;++i)
-					dst[mc->xpos*samplesperpixel+i]=src[i];
+				// Source component has no alpha channel, but the target image does.
+				if(HAS_ALPHA(type))
+				{
+					for(int i=0;i<mc->source->width;++i)
+					{
+						int j;
+						for(j=0;j<samplesperpixel-1;++j)
+						{
+							dst[(mc->xpos+i)*samplesperpixel+j]=src[i*mc->source->samplesperpixel+j];
+						}
+						dst[(mc->xpos+i)*samplesperpixel+j]=IS_SAMPLEMAX;
+					}
+				}
+				else
+				{
+					// Simplest case - neither source nor destination has an alpha channel.
+					for(int i=0;i<mc->source->width*samplesperpixel;++i)
+						dst[mc->xpos*samplesperpixel+i]=src[i];
+				}
 			}
 		}
 		ISMontage_Component *nmc=mc->next;
