@@ -79,6 +79,8 @@ IS_TIFFStrip::IS_TIFFStrip(ImageSource_TIFF *header,int row) : next(NULL), heade
 {
 	int i,j;
 
+	cerr << "In TIFFStrip constructor" << endl;
+
 	if((prev=header->strips))
 	{
 		while(prev->next)
@@ -96,6 +98,8 @@ IS_TIFFStrip::IS_TIFFStrip(ImageSource_TIFF *header,int row) : next(NULL), heade
 	if(lastrow>=header->height)
 		lastrow=header->height-1;
 
+	cerr << "Stripsize = " << header->stripsize << "  -  allocating" << endl;
+
 	imgdata=(unsigned char *)malloc(header->stripsize);
 
 	switch(header->photometric)
@@ -107,17 +111,28 @@ IS_TIFFStrip::IS_TIFFStrip(ImageSource_TIFF *header,int row) : next(NULL), heade
 					TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
 					break;
 				case 8:
+//					switch(header->samplesperpixel)
+//					{
+//						case 1:
+							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
+							break;
+//						case 2:
+//							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
+//							for(j=0;j<(header->stripsize/2);++j)
+//								imgdata[j]=imgdata[j*2];
+//							break;
+//						default:
+//							break;
+//					}
+					break;
+				case 16:
 					switch(header->samplesperpixel)
 					{
 						case 1:
 							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
 							break;
-						case 2:
-							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
-							for(j=0;j<(header->stripsize/2);++j)
-								imgdata[j]=imgdata[j*2];
-							break;
 						default:
+							cerr << "FIXME - 16-bit greyscale data with 2 samples per pixel not yet handled" << endl;
 							break;
 					}
 					break;
@@ -132,22 +147,40 @@ IS_TIFFStrip::IS_TIFFStrip(ImageSource_TIFF *header,int row) : next(NULL), heade
 						imgdata[j]=imgdata[j]^255;
 					break;
 				case 8:
+//					switch(header->samplesperpixel)
+//					{
+//						case 1:
+							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
+							for(j=0;j<(header->stripsize);++j)
+								imgdata[j]=255-imgdata[j];
+//							break;
+//						case 2:
+//							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
+//							for(j=0;j<(header->stripsize/2);++j)
+//								imgdata[j]=255-imgdata[j*2];
+//							break;
+//						default:
+//							break;
+//					}
+					break;
+				case 16:
 					switch(header->samplesperpixel)
 					{
 						case 1:
 							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
-							for(j=0;j<(header->stripsize);++j)
-								imgdata[j]=255-imgdata[j];
-							break;
-						case 2:
-							TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
-							for(j=0;j<(header->stripsize/2);++j)
-								imgdata[j]=255-imgdata[j*2];
+							{	// New scope for srcrow declaration
+								unsigned short *srcrow16=(unsigned short *)imgdata;
+								for(j=0;j<(header->stripsize/2);++j)
+									imgdata[j]=imgdata[j]^65535;
+							}
 							break;
 						default:
+							cerr << "FIXME - 16-bit greyscale data with 2 samples per pixel not yet handled" << endl;
 							break;
 					}
 					break;
+					// FIXME - handle 16-bit data!
+					break;
 			}
 			break;
 		case PHOTOMETRIC_PALETTE:
@@ -157,6 +190,7 @@ IS_TIFFStrip::IS_TIFFStrip(ImageSource_TIFF *header,int row) : next(NULL), heade
 			break;
 		case PHOTOMETRIC_RGB:
 		case PHOTOMETRIC_SEPARATED:
+			cerr << "Reading strip" << endl;
 			TIFFReadEncodedStrip(header->file, i, imgdata, (tsize_t)-1);
 			break;
 		default:
@@ -267,13 +301,14 @@ int ImageSource_TIFF::CountTIFFDirs(const char *filename,int &largestdir)
 }
 
 
-ImageSource_TIFF::ImageSource_TIFF(const char *filename)
+ImageSource_TIFF::ImageSource_TIFF(const char *filename) : ImageSource()
 {
-	ttile_t stripcount;
-	uint16 photometric,spp,bps;
-	uint32 width,height,sl;
-	uint32 stripsize;
-	float xres,yres;
+	ttile_t stripcount=0;
+	uint16 photometric=0,spp=0,bps=0;
+	uint32 width=0,height=0,sl=0;
+	uint32 stripsize=0;
+	float xres=72.0;
+	float yres=72.0;
 	uint16 resunit=RESUNIT_INCH;
 	uint16 *palettered,*palettegreen,*paletteblue;
 	uint16 inkset;
@@ -300,6 +335,9 @@ ImageSource_TIFF::ImageSource_TIFF(const char *filename)
 	TIFFGetField(file, TIFFTAG_IMAGELENGTH, &height);
 	TIFFGetField(file, TIFFTAG_ROWSPERSTRIP, &sl);
 
+	// If striplength is undefined, assume the image data is in a single strip.
+	if(sl==0) sl=height;
+
 	switch(bps)
 	{
 		case 1:
@@ -321,7 +359,19 @@ ImageSource_TIFF::ImageSource_TIFF(const char *filename)
 			if(bps==1)
 				type=IS_TYPE_BW;
 			else
-				type=IS_TYPE_GREY;
+			{
+				switch(spp)
+				{
+					case 1:
+						type=IS_TYPE_GREY;
+						break;
+					case 2:
+						type=IS_TYPE_GREYA;
+						break;
+					default:
+						break;
+				}
+			}
 			break;
 		case PHOTOMETRIC_PALETTE:
 			TIFFGetField(file, TIFFTAG_COLORMAP,&palettered,&palettegreen,&paletteblue);
@@ -364,7 +414,18 @@ ImageSource_TIFF::ImageSource_TIFF(const char *filename)
 			break;
 		case PHOTOMETRIC_SEPARATED:
 			TIFFGetField(file, TIFFTAG_INKSET, &inkset);
-			type=IS_TYPE_CMYK;
+			switch(spp)
+			{
+				case 4:
+					type=IS_TYPE_CMYK;
+					break;
+				case 5:
+					type=IS_TYPE_CMYKA;
+					break;
+				default:
+					type=IS_TYPE_DEVICEN;
+					break;
+			}
 			break;
 		default:
 			throw "Unsupported file format - must be either 1, 8 or 16-bit greyscale, RGB or CMYK...";
@@ -388,6 +449,8 @@ ImageSource_TIFF::ImageSource_TIFF(const char *filename)
 		yres*=2.54;
 	}
 
+	cerr << "Resolution: " << xres << " by " << yres << endl;
+
 	this->width=width;
 	this->height=height;
 	this->stripheight=sl;
@@ -409,10 +472,12 @@ ImageSource_TIFF::ImageSource_TIFF(const char *filename)
 
 	source_spp=samplesperpixel;
 
-	if(samplesperpixel==2)
-	{
-		this->spr/=2;
-	}
+//  This is no longer valid.  If memory serves it was to hack around Greyscale TIFFs with Alpha.
+//  FIXME: Verify that greyscale TIFFs with Alpha still work OK!
+//	if(samplesperpixel==2)
+//	{
+//		this->spr/=2;
+//	}
 	
 	cerr << "TIFF Samples per pixel: " << samplesperpixel << endl;
 	cerr << "Samples per row: " << this->spr << endl;
