@@ -22,7 +22,9 @@ GdkPixbuf *pixbuf_from_imagesource(ImageSource *is,
 
 	GdkPixbuf *pb;
 
-	switch(IS_TYPE_RGB)
+	cerr << "Converting image of type " << is->type << endl;
+
+	switch(is->type)
 	{
 		case IS_TYPE_RGB:
 		case IS_TYPE_RGBA:
@@ -55,7 +57,7 @@ GdkPixbuf *pixbuf_from_imagesource(ImageSource *is,
 				case IS_TYPE_RGBA:
 					for(int x=0;x<is->width;++x)
 					{
-						int a=255-ISTOEIGHT(src[x*4+3]);
+						int a=ISTOEIGHT(src[x*4+3]);
 						pixels[x*3]=(ISTOEIGHT(src[x*4])*a+redbg8*(255-a))/255;
 						pixels[x*3+1]=(ISTOEIGHT(src[x*4+1])*a+greenbg8*(255-a))/255;
 						pixels[x*3+2]=(ISTOEIGHT(src[x*4+2])*a+bluebg8*(255-a))/255;
