@@ -14,11 +14,11 @@
 #include "config.h"
 
 #include "dialogs.h"
-#include "support/generaldialogs.h"
+#include "miscwidgets/generaldialogs.h"
 #include "pixbufthumbnail/egg-pixbuf-thumbnail.h"
 #include "imagesource/pixbuf_from_imagesource.h"
-#include "support/rotatepixbuf.h"
-#include "support/maskpixbuf.h"
+#include "imageutils/rotatepixbuf.h"
+#include "imageutils/maskpixbuf.h"
 #include "support/thread.h"
 #include "support/progressthread.h"
 
@@ -29,10 +29,11 @@
 #include "imagesource/imagesource_mask.h"
 #include "imagesource/imagesource_rotate.h"
 #include "imagesource/imagesource_promote.h"
+#include "imagesource/imagesource_invert.h"
 
 #include "photoprint_state.h"
 #include "support/progress.h"
-#include "util.h"
+#include "support/util.h"
 #include "support/layoutrectangle.h"
 
 #include "layout_imageinfo.h"
@@ -146,6 +147,11 @@ class hr_payload
 		if(thread)
 			delete thread;
 	}
+	static bool testbreakfunc(void *ud)
+	{
+		Thread *t=(Thread *)ud;
+		return(t->TestBreak());
+	}
 	static int ThreadFunc(Thread *t,void *ud)
 	{
 		hr_payload *p=(hr_payload *)ud;
@@ -153,7 +159,28 @@ class hr_payload
 		p->thread=t;
 
 		cerr << "Subthread - about to obtain mutex" << endl;
-		p->ii->ObtainMutexShared();
+//		p->ii->ObtainMutexShared();
+		// To avoid a deadlock situation if, say, the Apply Profile dialog is open and GTK decides that
+		// now is a good time to redraw the window, we only attempt the mutex, and bail out if it fails.
+		int count=10;
+		while(!p->ii->AttemptMutexShared())
+		{
+			if(count==0)
+			{
+				cerr << "Giving up attempt on mutex - bailing out" << endl;
+				// The calling thread is waiting for us to acknowledge startup, so we have to send
+				// the Sync before bailing out.
+				t->SendSync();
+				g_timeout_add(1,hr_payload::CleanupFunc,p);
+				return(0);
+			}
+#ifdef WIN32
+			Sleep(50);
+#else
+			usleep(50000);
+#endif
+			--count;
+		}
 
 		t->SendSync();
 
@@ -218,13 +245,17 @@ class hr_payload
 			RectFit *fit=r.Fit(target,p->ii->allowcropping,p->ii->rotation,p->ii->crop_hpan,p->ii->crop_vpan);
 
 			if(fit->rotation)
-				is=new ImageSource_Rotate(is,fit->rotation);
+			{
+				ImageSource_Interruptible *ii=new ImageSource_Rotate(is,fit->rotation);
+				ii->SetTestBreak(testbreakfunc,t);
+				is=ii;
+			}
 			is=ISScaleImageBySize(is,fit->width,fit->height,IS_SCALING_AUTOMATIC);
 			delete fit;
 			// We create new Fit in the idle-function because the hpan/vpan may have changed.
 
 			ProgressThread prog(*t);
-			p->transformed=pixbuf_from_imagesource(is,255,255,255,&prog);
+			p->transformed=pixbuf_from_imagesource(is,p->ii->layout.bgcol.red>>8,p->ii->layout.bgcol.green>>8,p->ii->layout.bgcol.blue>>8,&prog);
 
 			delete is;
 
@@ -267,13 +298,25 @@ class hr_payload
 		p->ii->ReleaseMutex();
 		return(0);
 	}
+
+	// CleanupFunc - runs on the main thread's context.
 	static gboolean CleanupFunc(gpointer ud)
 	{
 		hr_payload *p=(hr_payload *)ud;
 		p->thread->SendSync();
+
+		// We clear the renderthread pointer in the ImageInfo here before deleting it
+		// to avoid the main thread trying to cancel it after deletion.
+		// This should be safe since this function runs on the main thread's context.
+		if(p->ii->hrrenderthread==p->thread)
+			p->ii->hrrenderthread=NULL;
+
 		delete p;
 		return(FALSE);
 	}
+
+	// IdleFunc - runs on the main thread's context,
+	// thus, can safely render into the UI.
 	static gboolean IdleFunc(gpointer ud)
 	{
 		// Once control reaches here the subthread should have
@@ -687,8 +730,8 @@ GdkPixbuf *Layout_ImageInfo::GetThumbnail()
 						h=(src->height*256)/src->width;
 					}
 					src=ISScaleImageBySize(src,w,h,IS_SCALING_NEARESTNEIGHBOUR);
-					transform = layout.factory->GetTransform(target,emb,customintent);
-					src=new ImageSource_CMS(src,transform);
+					if((transform = layout.factory->GetTransform(target,emb,customintent)))
+						src=new ImageSource_CMS(src,transform);
 					thumbnail=pixbuf_from_imagesource(src);
 					delete src;
 					src=NULL;
@@ -806,6 +849,7 @@ ImageSource *Layout_ImageInfo::ApplyMask(ImageSource *is)
 //			cerr << "Rotating mask" << endl;
 		}
 		mask=ISScaleImageBySize(mask,is->width,is->height,IS_SCALING_AUTOMATIC);
+		mask=new ImageSource_Invert(mask);
 		is=new ImageSource_Mask(is,mask);
 	}
 	return(is);
@@ -850,6 +894,16 @@ void Layout_ImageInfo::CancelRenderThread()
 	if(hrrenderthread)
 	{
 		hrrenderthread->Stop();
+
+		// Obtain the mutex - this won't succeed until the thread has finished whatever it's doing...
+		// We defer this so that, for instance, all threads can be cancelled before we start waiting...
+//		while(!PPEffectHeader::AttemptMutex())
+//		{
+//			cerr << "Can't get exclusive lock - performing main loop iteration" << endl;
+//			gtk_main_iteration();
+//		}
+//		ReleaseMutex();
+
 //		while(!hrrenderthread->TestFinished())
 //			gtk_main_iteration();
 //		delete hrrenderthread;
