@@ -18,10 +18,10 @@
 #include <iostream>
 #include <string.h>
 
-#include "support/generaldialogs.h"
+#include "miscwidgets/generaldialogs.h"
 #include "dialogs.h"
 #include "pixbufthumbnail/egg-pixbuf-thumbnail.h"
-#include "support/rotatepixbuf.h"
+#include "imageutils/rotatepixbuf.h"
 #include "imagesource/imagesource_util.h"
 #include "imagesource/imagesource_cms.h"
 #include "imagesource/imagesource_scale.h"
@@ -405,12 +405,6 @@ const char *Layout_NUp::GetType()
 	return("NUp");
 }
 
-void Layout_NUp::UpdatePageSize()
-{
-	int t=topmargin,l=leftmargin,r=rightmargin,b=bottommargin;
-	SetPageExtent(state.printer);
-	SetMargins(l,r,t,b);
-}
 
 void (*Layout_NUp::SetUnitFunc())(GtkWidget *wid,enum Units unit)
 {
