@@ -8,7 +8,7 @@
 
 #include "support/signature.h"
 #include "imagesource/imagesource.h"
-#include "print.h"
+#include "gp_cppsupport/gprinter.h"
 
 #include "layoutdb.h"
 #include "layout.h"
@@ -34,7 +34,6 @@ class Layout_NUp : public Layout, public Signature
 	virtual GtkWidget *CreateWidget();
 	virtual void RefreshWidget(GtkWidget *widget);
 	virtual ImageSource *GetImageSource(int page,CMColourDevice target=CM_COLOURDEVICE_PRINTER,CMTransformFactory *factory=NULL,int res=0);
-	void UpdatePageSize();
 	Layout_NUp_ImageInfo *ImageAt(int page, int row, int column);
 	virtual void (*SetUnitFunc())(GtkWidget *wid,enum Units unit);
 	virtual Layout_ImageInfo *ImageAtCoord(int x,int y);
