@@ -23,10 +23,10 @@
 #include <iostream>
 #include <string.h>
 
-#include "support/generaldialogs.h"
+#include "miscwidgets/generaldialogs.h"
 #include "dialogs.h"
 #include "pixbufthumbnail/egg-pixbuf-thumbnail.h"
-#include "support/rotatepixbuf.h"
+#include "imageutils/rotatepixbuf.h"
 #include "imagesource/imagesource_util.h"
 #include "imagesource/imagesource_crop.h"
 #include "imagesource/imagesource_rotate.h"
@@ -432,11 +432,6 @@ const char *Layout_Single::GetType()
 }
 
 
-void Layout_Single::UpdatePageSize()
-{
-	SetPageExtent(state.printer);
-}
-
 void (*Layout_Single::SetUnitFunc())(GtkWidget *wid,enum Units unit)
 {
 	return(pp_layout_single_set_unit);
@@ -475,3 +470,11 @@ Layout_ImageInfo *Layout_Single::NextSelected()
 }
 
 
+// We override this to set the top/left margin
+void Layout_Single::Print(Progress *p)
+{
+	xoffset=leftmargin;
+	yoffset=topmargin;
+	Layout::Print(p);
+}
+
