@@ -8,7 +8,7 @@
 
 #include "imagesource/imagesource.h"
 #include "support/pageextent.h"
-#include "print.h"
+#include "gp_cppsupport/gprinter.h"
 
 #include "layoutdb.h"
 #include "layout.h"
@@ -31,8 +31,8 @@ class Layout_Single : public Layout
 	virtual void DBToLayout(LayoutDB &db);
 	virtual GtkWidget *CreateWidget();
 	virtual void RefreshWidget(GtkWidget *widget);
+	virtual void Print(Progress *p);	// Overridden so we can set the top/left position...
 	virtual ImageSource *GetImageSource(int page,CMColourDevice target=CM_COLOURDEVICE_PRINTER,CMTransformFactory *factory=NULL,int res=0);
-	void UpdatePageSize();
 	virtual Layout_ImageInfo *FirstSelected();
 	virtual Layout_ImageInfo *NextSelected();
 	Layout_Single_ImageInfo *ImageAt(int page);
