@@ -4,8 +4,8 @@
 #include "layout.h"
 #include "support/configdb.h"
 #include "stpui_widgets/units.h"
-#include "printoutput.h"
-#include "print.h"
+#include "gp_cppsupport/printoutput.h"
+#include "gp_cppsupport/gprinter.h"
 #include "support/progress.h"
 #include "profilemanager/profilemanager.h"
 #include "support/searchpath.h"
