@@ -301,7 +301,8 @@ pp_cms_init (pp_CMS *ob)
 
 void pp_cms_populate(pp_CMS *ob,PhotoPrint_State *db)
 {
-	char *pf,*pf2;
+	const char *pf;
+	char *pf2;
 
 	cerr << "Populating PP_CMS..." << endl;
 
@@ -309,7 +310,7 @@ void pp_cms_populate(pp_CMS *ob,PhotoPrint_State *db)
 	pf=db->profilemanager.FindString("PrinterProfile");
 	if(pf && strlen(pf))
 	{
-		if((pf2=db->profilemanager.Search(pf)))
+		if((pf2=db->profilemanager.SearchPaths(pf)))
 		{
 			cerr << "Setting printer profile to " << pf2 << endl;
 			profileselector_set_filename(PROFILESELECTOR(ob->printerprof),pf2);
@@ -324,7 +325,7 @@ void pp_cms_populate(pp_CMS *ob,PhotoPrint_State *db)
 	cerr << "Default RGB Profile" << pf;
 	if(pf && strlen(pf))
 	{
-		if((pf2=db->profilemanager.Search(pf)))
+		if((pf2=db->profilemanager.SearchPaths(pf)))
 		{
 			cerr << "Setting RGB profile to " << pf2 << endl;
 			profileselector_set_filename(PROFILESELECTOR(ob->rgbprof),pf2);
@@ -339,7 +340,7 @@ void pp_cms_populate(pp_CMS *ob,PhotoPrint_State *db)
 	cerr << "Default CMYK Profile" << pf;
 	if(pf && strlen(pf))
 	{
-		if((pf2=db->profilemanager.Search(pf)))
+		if((pf2=db->profilemanager.SearchPaths(pf)))
 		{
 			cerr << "Setting CMYK profile to " << pf2 << endl;
 			profileselector_set_filename(PROFILESELECTOR(ob->cmykprof),pf2);
@@ -353,7 +354,7 @@ void pp_cms_populate(pp_CMS *ob,PhotoPrint_State *db)
 	pf=db->profilemanager.FindString("MonitorProfile");
 	if(pf && strlen(pf))
 	{
-		if((pf2=db->profilemanager.Search(pf)))
+		if((pf2=db->profilemanager.SearchPaths(pf)))
 		{
 			cerr << "Setting Monitor profile to " << pf2 << endl;
 			profileselector_set_filename(PROFILESELECTOR(ob->monitorprof),pf2);
@@ -367,7 +368,7 @@ void pp_cms_populate(pp_CMS *ob,PhotoPrint_State *db)
 
 	gtk_option_menu_set_history(GTK_OPTION_MENU(ob->displaymode),db->profilemanager.FindInt("ProofMode"));
 
-	char *cs=db->FindString("PrintColourSpace");
+	const char *cs=db->FindString("PrintColourSpace");
 	if(strcmp(cs,"RGB")==0)
 		gtk_option_menu_set_history(GTK_OPTION_MENU(ob->colourspace),0);
 	else if(strcmp(cs,"CMYK")==0)
