@@ -6,13 +6,14 @@
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkexpander.h>
 
 #include "stpui_widgets/dimension.h"
 #include "stpui_widgets/stpui_combo.h"
-#include "support/tiffsave.h"
 #include "layout.h"
 #include "dialogs.h"
 #include "pp_pageextent.h"
+#include "pp_imagecontrol.h"
 #include "pp_layout_carousel_pageview.h"
 #include "pp_layout_carousel.h"
 #include "layout_carousel.h"
@@ -55,6 +56,16 @@ static void pe_changed(GtkWidget *wid,gpointer *ob)
 }
 
 
+static void ic_changed(GtkWidget *wid,gpointer *ob)
+{
+	cerr << "Got changed signal from ImageControl" << endl;
+	pp_Layout_Carousel *lo=(pp_Layout_Carousel *)ob;
+	pp_Layout_Carousel_PageView *pv=PP_LAYOUT_CAROUSEL_PAGEVIEW(lo->pageview);
+	pp_layout_carousel_pageview_refresh(PP_LAYOUT_CAROUSEL_PAGEVIEW(pv));
+	g_signal_emit(G_OBJECT (ob),pp_layout_carousel_signals[CHANGED_SIGNAL], 0);
+}
+
+
 static void segments_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Carousel *lo=(pp_Layout_Carousel *)ob;
@@ -135,6 +146,7 @@ static void pageview_popupmenu(GtkWidget *wid,gpointer *ob)
 static void pageview_selection_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_Carousel *lo=(pp_Layout_Carousel *)ob;
+	pp_imagecontrol_refresh(PP_IMAGECONTROL(lo->imagecontrol));
 	g_signal_emit(G_OBJECT (lo),pp_layout_carousel_signals[SELECTIONCHANGED_SIGNAL], 0);
 }
 
@@ -189,12 +201,8 @@ pp_layout_carousel_new (PhotoPrint_State *state)
 	ob->state=state;
 	
 	GtkWidget *vbox;
-	GtkWidget *vbox2;
 	GtkWidget *hbox;
 	GtkWidget *label;
-	GtkWidget *tmp;
-
-	ob->sizegroup = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 	
 	GtkWidget *frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
@@ -210,33 +218,85 @@ pp_layout_carousel_new (PhotoPrint_State *state)
 	gtk_container_add (GTK_CONTAINER (frame), ob->pageview);
 	gtk_widget_show (ob->pageview);
 
+
+#if 0
 	GtkWidget *scrollwin=gtk_scrolled_window_new(NULL,NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-	vbox = gtk_vbox_new (FALSE, 5);
-	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), vbox);
+	GtkWidget *hbox2=gtk_hbox_new(FALSE,0);
+	gtk_widget_show (hbox2);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox2),vbox,TRUE,TRUE,5);
+	
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), hbox2);
 	gtk_box_pack_start(GTK_BOX(&ob->hbox),scrollwin,FALSE,FALSE,0);
 	gtk_widget_show (vbox);
 	gtk_widget_show (scrollwin);
+#endif
+
+
+	// Scroll Window
+
+	GtkWidget *scrollwin=gtk_scrolled_window_new(NULL,NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
+                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+
+	vbox = gtk_vbox_new (FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(&ob->hbox),vbox,FALSE,FALSE,0);
+	gtk_widget_show (vbox);
+	gtk_box_pack_start(GTK_BOX(vbox),scrollwin,TRUE,TRUE,0);
+	gtk_widget_show (scrollwin);
+
+
+	// Page number
+
+	hbox=gtk_hbox_new(FALSE,5);
+	label=gtk_label_new(_("Page:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
+	gtk_widget_show(label);
+
+	ob->page=gtk_spin_button_new_with_range(1.0,2.0,1.0);
+	g_signal_connect(G_OBJECT(ob->page),"value-changed",G_CALLBACK(page_changed),ob);
+	gtk_widget_show(ob->page);
+
+	gtk_box_pack_start(GTK_BOX(hbox),ob->page,FALSE,FALSE,0);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
+	gtk_widget_show(hbox);
+
+
+	// Contents of scrollwindow
+
+	GtkWidget *hbox2=gtk_hbox_new(FALSE,0);
+	gtk_widget_show (hbox2);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox2),vbox,TRUE,TRUE,5);
+	
+	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrollwin), hbox2);
+//	gtk_container_foreach(GTK_CONTAINER(scrollwin),killshadow,NULL);
+	gtk_widget_show (vbox);
+
 
 	// Carousel
 	
-	frame=gtk_frame_new(_("Carousel"));
+	frame=gtk_expander_new(_("Carousel"));
+	gtk_expander_set_expanded(GTK_EXPANDER(frame),true);
 	gtk_box_pack_start(GTK_BOX(vbox),frame,FALSE,FALSE,0);
-	gtk_container_set_border_width(GTK_CONTAINER(frame),5);
 	gtk_widget_show(frame);
 
-	vbox2=gtk_vbox_new(FALSE,0);
-	gtk_container_add(GTK_CONTAINER(frame),vbox2);
-	gtk_widget_show(vbox2);
-
+	GtkWidget *table=gtk_table_new(2,4,false);
+	gtk_table_set_row_spacings(GTK_TABLE(table),5);
+//	gtk_table_set_row_spacing(GTK_TABLE(table),4,5);
+	gtk_table_set_col_spacings(GTK_TABLE(table),3);
+	gtk_container_add(GTK_CONTAINER(frame),table);
+	gtk_widget_show(table);
+	
 
 	//    Segments spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
-	
 	label=gtk_label_new(_("Segments:"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
 	gtk_widget_show(label);
 
 	ob->segments=gtk_spin_button_new_with_range(4.0,16.0,2.0);
@@ -244,19 +304,14 @@ pp_layout_carousel_new (PhotoPrint_State *state)
 	g_signal_connect(G_OBJECT(ob->segments),"value-changed",G_CALLBACK(segments_changed),ob);
 	gtk_widget_show(ob->segments);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),ob->segments);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->segments,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),ob->segments,1,2,0,1);
 
 
 	//    Overlap spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
-	
 	label=gtk_label_new(_("Overlap (%):"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
 	gtk_widget_show(label);
 
 	ob->overlap=gtk_spin_button_new_with_range(0.0,50.0,1.0);
@@ -264,19 +319,14 @@ pp_layout_carousel_new (PhotoPrint_State *state)
 	g_signal_connect(G_OBJECT(ob->overlap),"value-changed",G_CALLBACK(overlap_changed),ob);
 	gtk_widget_show(ob->overlap);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),ob->overlap);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->overlap,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),ob->overlap,1,2,1,2);
 
 
 	//    AngleOffset spin button
 
-	hbox=gtk_hbox_new(FALSE,0);
-	
 	label=gtk_label_new(_("Starting angle:"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,2,3);
 	gtk_widget_show(label);
 
 	ob->angleoffset=gtk_spin_button_new_with_range(0.0,90.0,1.0);
@@ -284,44 +334,44 @@ pp_layout_carousel_new (PhotoPrint_State *state)
 	g_signal_connect(G_OBJECT(ob->angleoffset),"value-changed",G_CALLBACK(angleoffset_changed),ob);
 	gtk_widget_show(ob->angleoffset);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),ob->angleoffset);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->angleoffset,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),ob->angleoffset,1,2,2,3);
 
 
 	//    Inner radius dimension widget
-
-	hbox=gtk_hbox_new(FALSE,0);
 	
 	label=gtk_label_new(_("Inner Radius:"));
-	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,5);
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
+	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,3,4);
 	gtk_widget_show(label);
 
 	enum Units unit=state->GetUnits();
 
 	ob->innerradius=dimension_new(0.0,100.0,unit);
-	g_signal_connect(G_OBJECT(ob->innerradius),"value-changed",G_CALLBACK(innerradius_changed),ob);
-//	gtk_spin_button_set_value(GTK_SPIN_BUTTON(ob->overlap),l->GetOverlap());
+//	g_signal_connect(G_OBJECT(ob->innerradius),"value-changed",G_CALLBACK(innerradius_changed),ob);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(ob->overlap),l->GetOverlap());
 	g_signal_connect(G_OBJECT(ob->innerradius),"value-changed",G_CALLBACK(innerradius_changed),ob);
 	gtk_widget_show(ob->innerradius);
 
-	gtk_size_group_add_widget(GTK_SIZE_GROUP(ob->sizegroup),ob->innerradius);
-	gtk_box_pack_start(GTK_BOX(hbox),ob->innerradius,FALSE,FALSE,5);
-
-	gtk_box_pack_start(GTK_BOX(vbox2),hbox,FALSE,FALSE,5);
-	gtk_widget_show(hbox);
+	gtk_table_attach_defaults(GTK_TABLE(table),ob->innerradius,1,2,3,4);
 
 
 	// PageExtent
 
-	ob->pageextent=pp_pageextent_new((Layout_Carousel *)ob->state->layout,ob->state,ob->sizegroup);
+	ob->pageextent=pp_pageextent_new((Layout_Carousel *)ob->state->layout,ob->state);
 	g_signal_connect(G_OBJECT(ob->pageextent),"changed",G_CALLBACK(pe_changed),ob);
 	gtk_box_pack_start(GTK_BOX(vbox),ob->pageextent,FALSE,FALSE,0);
 	gtk_widget_show(ob->pageextent);
 
 
+	// ImageControl
+
+	ob->imagecontrol=pp_imagecontrol_new(ob->state->layout);
+	gtk_box_pack_start(GTK_BOX(vbox),ob->imagecontrol,TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(ob->imagecontrol),"changed",G_CALLBACK(ic_changed),ob);
+	gtk_widget_show(ob->imagecontrol);
+
+
+#if 0
 	// Spacer box
 
 	tmp=gtk_vbox_new(FALSE,0);
@@ -333,6 +383,7 @@ pp_layout_carousel_new (PhotoPrint_State *state)
 
 	hbox=gtk_hbox_new(FALSE,5);
 	label=gtk_label_new(_("Page:"));
+	gtk_misc_set_alignment(GTK_MISC(label),1.0,0.5);
 	gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
 	gtk_widget_show(label);
 
@@ -345,9 +396,7 @@ pp_layout_carousel_new (PhotoPrint_State *state)
 
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	gtk_widget_show(hbox);
-
-	g_object_unref(G_OBJECT(ob->sizegroup));
-	ob->sizegroup=NULL;
+#endif
 
 	pp_layout_carousel_refresh(ob);
 
@@ -412,4 +461,5 @@ pp_layout_carousel_init (pp_Layout_Carousel *ob)
 {
 	ob->state=NULL;
 	ob->pageview=NULL;
+	ob->imagecontrol=NULL;
 }
