@@ -25,7 +25,6 @@
 
 #include "pp_layout_nup.h"
 
-#include "support/tiffsave.h"
 #include "layout.h"
 #include "dialogs.h"
 
@@ -60,7 +59,6 @@ static void pe_changed(GtkWidget *wid,gpointer *ob)
 {
 	pp_Layout_NUp *lo=(pp_Layout_NUp *)ob;
 	Layout_NUp *l=(Layout_NUp*)lo->state->layout;
-	l->ReCalc();
 	l->FlushHRPreviews();
 	pp_Layout_NUp_PageView *pv=PP_LAYOUT_NUP_PAGEVIEW(lo->pageview);
 	pp_layout_nup_pageview_refresh(PP_LAYOUT_NUP_PAGEVIEW(pv));
@@ -149,7 +147,6 @@ void pp_layout_nup_refresh(pp_Layout_NUp *ob)
 	gtk_spin_button_set_range(GTK_SPIN_BUTTON(ob->page),1.0,pages);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(ob->page),ob->state->layout->GetCurrentPage()+1);
 	pp_layout_nup_pageview_refresh(pv);
-	pp_sigcontrol_refresh(PP_SIGCONTROL(ob->sigcontrol));
 	pp_pageextent_refresh(PP_PAGEEXTENT(ob->pageextent));
 	pp_imagecontrol_refresh(PP_IMAGECONTROL(ob->imagecontrol));
 }
