@@ -6,7 +6,7 @@
 #include "pp_menu_file.h"
 #include "pp_mainwindow.h"
 #include "dialogs.h"
-#include "support/generaldialogs.h"
+#include "miscwidgets/generaldialogs.h"
 #include "support/progressbar.h"
 
 #include "config.h"
@@ -38,7 +38,7 @@ static void file_open_preset(GtkAction *action,gpointer *ob)
 	if(filename)
 	{
 		mw->state->SetFilename(filename);
-		mw->state->ParseFile();
+		mw->state->ParseConfigFile();
 		
 		g_free(filename);
 
@@ -51,7 +51,7 @@ static void file_save_preset(GtkAction *action,gpointer *ob)
 {
 	pp_MainWindow *mw=(pp_MainWindow *)ob;
 	savegeometry(mw);
-	mw->state->SaveFile();
+	mw->state->SaveConfigFile();
 }
 
 
@@ -64,7 +64,7 @@ static void file_save_as(GtkAction *action,gpointer *ob)
 	if(filename)
 	{
 		mw->state->SetFilename(filename);
-		mw->state->SaveFile();
+		mw->state->SaveConfigFile();
 	
 		g_free(filename);
 	}
@@ -76,7 +76,7 @@ static void file_save_default(GtkWidget *wid,gpointer *ob)
 	pp_MainWindow *mw=(pp_MainWindow *)ob;
 	savegeometry(mw);
 	mw->state->SetDefaultFilename();
-	mw->state->SaveFile();
+	mw->state->SaveConfigFile();
 }
 
 
@@ -118,7 +118,6 @@ static void file_print(GtkAction *action,gpointer *ob)
 
 static void file_quit(GtkAction *action,gpointer ob)
 {
-	cerr << "UserData: " << (long)ob << endl;
 	gtk_main_quit();
 }
 
