@@ -11,7 +11,7 @@
 
 #include "pp_mainwindow.h"
 #include "dialogs.h"
-#include "support/generaldialogs.h"
+#include "miscwidgets/generaldialogs.h"
 #include "support/progressbar.h"
 #include "support/pathsupport.h"
 #include "support/layoutrectangle.h" // For rotation enums
@@ -233,10 +233,15 @@ static void imagemenu_setcolourprofile(GtkAction *act,gpointer *ob)
 {
 	pp_MainWindow *mw=(pp_MainWindow *)ob;
 	Layout_ImageInfo *ii=mw->state->layout->FirstSelected();
-	ii->ObtainMutex();
-	SetCustomProfileDialog(&mw->window,*mw->state,ii);
-	ii->ReleaseMutex();
-	pp_mainwindow_refresh(mw);
+	if(ii)
+	{
+		ii->ObtainMutex();
+		SetCustomProfileDialog(&mw->window,*mw->state,ii);
+		ii->ReleaseMutex();
+		pp_mainwindow_refresh(mw);
+	}
+	else
+		ErrorMessage_Dialog(_("Please select an image first!"),GTK_WIDGET(mw));
 }
 
 
