@@ -126,6 +126,14 @@ CMSProfile::CMSProfile(char *srcbuf,int length) : md5(NULL), generated(false), f
 }
 
 
+CMSProfile::CMSProfile() : md5(NULL), generated(true), filename(NULL)
+{
+	if(!(prof=cmsCreate_sRGBProfile()))
+		throw "Can't create virtual sRGB profile";
+	CalcMD5();
+}
+
+
 CMSProfile::CMSProfile(const CMSProfile &src) : md5(NULL), generated(src.generated), filename(NULL)
 {
 	cerr << "In CMSProfile Copy Constructor" << endl;
