@@ -8,7 +8,8 @@
  *
  */
 
-
+#include <cstdlib>
+#include <cstring>
 #include <iostream>
 
 #include <gtk/gtk.h>
@@ -20,6 +21,14 @@
 
 #include "progressbar.h"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "gettext.h"
+#define _(x) gettext(x)
+#define N_(x) gettext_noop(x)
+
 using namespace std;
 
 
@@ -38,8 +47,8 @@ ProgressBar::ProgressBar(const char *message,bool cancel,GtkWidget *parent)
 	window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	if(parent)
 		gtk_window_set_transient_for(GTK_WINDOW(window),GTK_WINDOW(parent));
-	gtk_window_set_title(GTK_WINDOW(window),"Progress...");
-	gtk_window_set_default_size(GTK_WINDOW(window),10,10);
+	gtk_window_set_title(GTK_WINDOW(window),_("Progress..."));
+	gtk_window_set_default_size(GTK_WINDOW(window),150,30);
 	gtk_widget_show(window);
 	gtk_container_set_border_width(GTK_CONTAINER(window),10);
 
@@ -50,6 +59,7 @@ ProgressBar::ProgressBar(const char *message,bool cancel,GtkWidget *parent)
 	if(this->message)
 	{
 		label=gtk_label_new(this->message);
+		gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_CENTER);
 		gtk_box_pack_start(GTK_BOX(vbox),label,FALSE,FALSE,0);
 		gtk_widget_show(label);
 	}
