@@ -10,11 +10,13 @@ class ProgressBar : public Progress
 	ProgressBar(const char *message,bool cancelbutton,GtkWidget *parent=NULL);
 	~ProgressBar();
 	bool DoProgress(int i,int maxi);
+	void SetMessage(const char *msg);
 	static void cancel_callback(GtkWidget *wid,gpointer *ob);
 	private:
-	const char *message;
+	char *message;
 	GtkWidget *window;
 	GtkWidget *progressbar;
+	GtkWidget *label;
 	bool cancelled;
 };
 
