@@ -12,50 +12,7 @@ using namespace std;
 
 #include "ptmutex.h"
 
-// GThread-based implementation - 
-// Not currently used - needs to be migrated to GStaticRecMutex
-// and since it's no more guaranteed than pthreads to be available on Win32
-// it might make more sense to forget about the GLib implementation and 
-// use Win32 thread functions instead.
-
-//#ifdef G_THREADS_ENABLED
-#if 0
-
-
-PTMutex::PTMutex() : mutex(NULL)
-{
-	if (!g_thread_supported ())
-		g_thread_init (NULL);
-
-	mutex=g_mutex_new();
-}
-
-
-PTMutex::~PTMutex()
-{
-	if(mutex)
-		g_mutex_free(mutex);
-}
-
-
-void PTMutex::ObtainMutex()
-{
-	g_mutex_lock(mutex);
-}
-
-
-bool PTMutex::AttemptMutex()
-{
-	return(g_mutex_trylock(mutex));
-}
-
-
-void PTMutex::ReleaseMutex()
-{
-	g_mutex_unlock(mutex);
-}
-
-#elif defined HAVE_LIBPTHREAD || defined HAVE_LIBPTHREADGC2
+// #if defined HAVE_LIBPTHREAD || defined HAVE_LIBPTHREADGC2
 
 // pthreads-based implementation
 
@@ -97,8 +54,8 @@ void PTMutex::ReleaseMutex()
 	pthread_mutex_unlock(&mutex);
 }
 
-#else
-
+// #else
+#if 0
 // Dummy implementation.  Obtaining the mutex always succeeds.
 
 PTMutex::PTMutex()
