@@ -18,7 +18,7 @@
 
 class LayoutRectangle;
 
-class Signature : public PageExtent
+class Signature : public virtual PageExtent
 {
 	public:
 	Signature(int rows=1,int columns=1);
@@ -30,33 +30,30 @@ class Signature : public PageExtent
 	void SetPaperSize(int width,int height);
 	void SetMargins(int left,int right,int top,int bottom);
 	void SetGutters(int hgutter,int vgutter);
+	void SetHGutter(int gutter);
+	void SetVGutter(int gutter);
 	void SetColumns(int columns);
 	void SetRows(int rows);
-	int GetColumns()
-	{
-		return columns;
-	}
-	int GetRows()
-	{
-		return rows;
-	}
-	int GetHGutter()
-	{
-		return hgutter;
-	}
-	int GetVGutter()
-	{
-		return vgutter;
-	}
+	void SetCellWidth(int width);
+	void SetCellHeight(int height);
+	int GetCellWidth();
+	int GetCellHeight();
+	int GetColumns();
+	int GetRows();
+	int GetHGutter();
+	int GetVGutter();
 	LayoutRectangle *GetLayoutRectangle(int row,int column);
 	void EqualiseMargins();
 	void ReCalc();
+	void ReCalcByCellSize();
 	int ColumnAt(int xpos);
 	int RowAt(int ypos);
 	private:
 	int hgutter,vgutter;
 	int rows,columns;
 	float celwidth,celheight;
+	int rightpadding,bottompadding;
+	bool absolutemode;				// Used to track whether we're recalcing in terms of rows/columns or cell size.
 };
 
 #endif
